{% extends 'base.html' %}

{% load i18n %}
{% block title %}{% trans "Action" %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("Action") %}
{% endblock page_header %}

{% block main %}
    <div class="row">
   <div class="col-sm-12">
       <pre>{{ data }}</pre>
   </div>
    </div>

{% endblock %}
